"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.watch = watch;
/**
 * 观察一个或多个变量的变化
 * @param items 要被监听的变量列表
 * @param callback 回调函数
 * @param eventType 要监听的事件类型
 * @returns 返回一个 off 方法用于取消监听
 */
function watch(items, callback, eventType = ['set', 'add', 'delete', 'update']) {
    const wrappers = eventType.map(type => [type, function (...args) { callback(type, args); }]);
    for (const item of items) {
        for (const wrapper of wrappers) {
            item.on(...wrapper);
        }
    }
    return function off() {
        for (const item of items) {
            for (const wrapper of wrappers) {
                item.off(...wrapper);
            }
        }
    };
}
